@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -26,6 +27,23 @@
 
 #include "gmime-stream-filter.h"
 
+
+/**
+ * SECTION: gmime-stream-filter
+ * @title: GMimeStreamFilter
+ * @short_description: A filtering stream
+ * @see_also: #Filters
+ *
+ * A #GMimeStream meant for filtering data passing through it.
+ *
+ * This stream class is useful for converting data of one type to
+ * another using #GMimeFilter objects.
+ *
+ * When data passes through a #GMimeStreamFilter, it will pass through
+ * #GMimeFilter filters in the order they were added.
+ **/
+
+
 #define READ_PAD (64)		/* bytes padded before buffer */
 #define READ_SIZE (4096)
 
@@ -61,10 +79,10 @@ static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
 static int stream_reset (GMimeStream *stream);
-static off_t stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-static off_t stream_tell (GMimeStream *stream);
+static gint64 stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
+static gint64 stream_tell (GMimeStream *stream);
 static ssize_t stream_length (GMimeStream *stream);
-static GMimeStream *stream_substream (GMimeStream *stream, off_t start, off_t end);
+static GMimeStream *stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
 
 static GMimeStreamClass *parent_class = NULL;
@@ -84,7 +102,7 @@ g_mime_stream_filter_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeStreamFilter),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_stream_filter_init,
 		};
 		
@@ -322,13 +340,13 @@ stream_reset (GMimeStream *stream)
 	return 0;
 }
 
-static off_t
-stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
+static gint64
+stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 {
 	return -1;
 }
 
-static off_t
+static gint64
 stream_tell (GMimeStream *stream)
 {
 	return -1;
@@ -341,12 +359,12 @@ stream_length (GMimeStream *stream)
 }
 
 static GMimeStream *
-stream_substream (GMimeStream *stream, off_t start, off_t end)
+stream_substream (GMimeStream *stream, gint64 start, gint64 end)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
 	GMimeStreamFilter *sub;
 	
-	sub = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL);
+	sub = g_object_newv (GMIME_TYPE_STREAM_FILTER, 0, NULL);
 	sub->source = filter->source;
 	g_object_ref (sub->source);
 	
@@ -381,22 +399,22 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 
 
 /**
- * g_mime_stream_filter_new_with_stream:
+ * g_mime_stream_filter_new:
  * @stream: source stream
  *
- * Creates a new GMimeStreamFilter object using @stream as the source
+ * Creates a new #GMimeStreamFilter object using @stream as the source
  * stream.
  *
- * Returns a new filter stream with @stream as its source.
+ * Returns: a new filter stream with @stream as its source.
  **/
 GMimeStream *
-g_mime_stream_filter_new_with_stream (GMimeStream *stream)
+g_mime_stream_filter_new (GMimeStream *stream)
 {
 	GMimeStreamFilter *filter;
 	
 	g_return_val_if_fail (GMIME_IS_STREAM (stream), NULL);
 	
-	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL);
+	filter = g_object_newv (GMIME_TYPE_STREAM_FILTER, 0, NULL);
 	filter->source = stream;
 	g_object_ref (stream);
 	
@@ -410,25 +428,26 @@ g_mime_stream_filter_new_with_stream (GMimeStream *stream)
 
 /**
  * g_mime_stream_filter_add:
- * @fstream: filter stream
- * @filter: filter
+ * @stream: a #GMimeStreamFilter
+ * @filter: a #GMimeFilter
  *
- * Adds a @filter to @fstream.
+ * Adds @filter to @stream. Filters are applied in the same order in
+ * which they are added.
  *
- * Returns an id for the filter.
+ * Returns: an id for the filter.
  **/
 int
-g_mime_stream_filter_add (GMimeStreamFilter *fstream, GMimeFilter *filter)
+g_mime_stream_filter_add (GMimeStreamFilter *stream, GMimeFilter *filter)
 {
 	struct _GMimeStreamFilterPrivate *priv;
 	struct _filter *f, *fn;
 	
-	g_return_val_if_fail (GMIME_IS_STREAM_FILTER (fstream), -1);
+	g_return_val_if_fail (GMIME_IS_STREAM_FILTER (stream), -1);
 	g_return_val_if_fail (GMIME_IS_FILTER (filter), -1);
 	
 	g_object_ref (filter);
 	
-	priv = fstream->priv;
+	priv = stream->priv;
 	
 	fn = g_new (struct _filter, 1);
 	fn->next = NULL;
@@ -448,21 +467,21 @@ g_mime_stream_filter_add (GMimeStreamFilter *fstream, GMimeFilter *filter)
 
 /**
  * g_mime_stream_filter_remove:
- * @fstream: filter stream
+ * @stream: a #GMimeStreamFilter
  * @id: filter id
  *
  * Removed a filter from the stream based on the id (as returned from
  * filter_add).
  **/
 void
-g_mime_stream_filter_remove (GMimeStreamFilter *fstream, int id)
+g_mime_stream_filter_remove (GMimeStreamFilter *stream, int id)
 {
 	struct _GMimeStreamFilterPrivate *priv;
 	struct _filter *f, *fn;
 	
-	g_return_if_fail (GMIME_IS_STREAM_FILTER (fstream));
+	g_return_if_fail (GMIME_IS_STREAM_FILTER (stream));
 	
-	priv = fstream->priv;
+	priv = stream->priv;
 	
 	if (id == -1)
 		return;
